Activity Stream Documentation
==============================

:Authors:
   Justin Quick <justquick@gmail.com> and many others listed in AUTHORS.txt
:Version: 0.4.0


::

    pip install django-activity-stream==0.4.0beta1

Django Activity Stream is a way of creating activities generated by the actions on your site.
Action events are categorized by four main components.

 * ``Actor``. The object that performed the action.
 * ``Verb``. The verb phrase of the action performed.
 * ``Action Object``. *(Optional)* The object linked to the action itself.
 * ``Target``. *(Optional)* The object that the verb is enacted on.

``Actor``, ``Action Object`` and ``Target`` are ``GenericForeignKeys`` to any arbitrary Django object.
An action is a description of an action that was performed (``Verb``) at some instant in time by some ``Actor`` on some optional ``Target`` that results in an ``Action Object`` getting created/updated/deleted.

For example: ``<justquick>`` *(actor)* ``<closed>`` *(verb)* ``<issue 1>`` *(object)* on ``<activity-stream>`` *(target)* 12 hours ago

Nomenclature of this specification is based on the `Atom Activity Streams Spec <http://activitystrea.ms/specs/atom/1.0/>`_

For complete documenation see `Django Activity Stream Documentation <http://justquick.github.com/django-activity-stream/>`_